@@ -308,23 +308,24 @@ installSBT <- function(installPath, javaConf, verbose, attempt=1) {
 
 javaSpecifics <- function(javaCmd,verbose) {
   if ( verbose ) cat("  ... querying Java specifics.\n")
-  response <- system2(path.expand(javaCmd),"-version",stdout=TRUE,stderr=TRUE)
+  javaCmd <- normalizePath(javaCmd, mustWork=FALSE)
+  response <- system2(javaCmd,"-version",stdout=TRUE,stderr=TRUE)
   # Get version information
   versionRegexp <- '(java|openjdk) version "([^"]*)".*'
   line <- response[grepl(versionRegexp,response)]
   if ( length(line) != 1 ) return(paste0("cannot determine Java version.  Output is:\n",paste(response,collapse="\n")))
   versionString <- gsub(versionRegexp,"\\2",line)
-  versionParts <- strsplit(versionString,"\\.")[[1]]
-  versionNumber <- if ( versionParts[1] == '1' ) {
-    as.numeric(versionParts[2])
-  } else {
-    as.numeric(versionParts[1])
-  }
-  if ( ! ( versionNumber %in% c(8,9,10,11) ) ) return(paste0("unsupported Java version: ",versionString))
+  versionParts <- strsplit(versionString,"(\\.|-)")[[1]]
+  versionNumberString <- if ( versionParts[1] == '1' ) versionParts[2] else versionParts[1]
+  versionNumber <- tryCatch(
+    as.numeric(versionNumberString),
+    warning=function(e) 0
+  )
+  if ( versionNumber < 8 ) return(paste0("unsupported Java version: ",versionString))
   # Determine if 32 or 64 bit
   bit <- if ( any(grepl('^(Java HotSpot|OpenJDK).* 64-Bit (Server|Client) VM.*$',response)) ||
               any(grepl('^IBM .* amd64-64 .*$',response)) ) 64 else 32
-  list(javaCmd=normalizePath(javaCmd), javaMajorVersion=versionNumber, javaArchitecture=bit)
+  list(javaCmd=javaCmd, javaMajorVersion=versionNumber, javaArchitecture=bit)
 }
 
 setJavaEnv <- function(javaConf) {
@@ -346,7 +347,7 @@ scalaSpecifics <- function(scalaCmd,javaConf,verbose) {
   if ( verbose ) cat("  ... querying Scala specifics.\n")
   oldJavaEnv <- setJavaEnv(javaConf)
   info <- tryCatch({
-    system2(normalizePath(scalaCmd),c("-nobootcp","-nc","-e",shQuote('import util.Properties._; println(Seq(versionNumberString,scalaHome,javaHome).mkString(lineSeparator))')),stdout=TRUE,stderr=FALSE)
+    system2(normalizePath(scalaCmd,mustWork=FALSE),c("-nobootcp","-nc","-e",shQuote('import util.Properties._; println(Seq(versionNumberString,scalaHome,javaHome).mkString(lineSeparator))')),stdout=TRUE,stderr=FALSE)
    }, warning=function(e) "")
   setJavaEnv(oldJavaEnv)
   fullVersion <- info[1]
@@ -355,10 +356,10 @@ scalaSpecifics <- function(scalaCmd,javaConf,verbose) {
   supportedVersions <- names(scalaVersionJARs())
   if ( ( length(supportedVersions) > 0 ) && ! ( majorVersion %in% supportedVersions ) ) paste0("unsupported Scala version: ",majorVersion)
   else {
-    if ( ( majorVersion == "2.11" ) && ( as.numeric(javaConf$javaMajorVersion) > 8 ) ) {
+    if ( ( majorVersion == "2.11" ) && ( javaConf$javaMajorVersion > 8 ) ) {
       sprintf("Scala %s is not supported on Java %s.",majorVersion,javaConf$javaMajorVersion)
     } else {
-      list(scalaHome=normalizePath(info[2]), scalaCmd=normalizePath(scalaCmd), scalaMajorVersion=majorVersion, scalaFullVersion=fullVersion, javaHome=normalizePath(info[3]))
+      list(scalaHome=normalizePath(info[2],mustWork=FALSE), scalaCmd=normalizePath(scalaCmd,mustWork=FALSE), scalaMajorVersion=majorVersion, scalaFullVersion=fullVersion, javaHome=normalizePath(info[3],mustWork=FALSE))
     }
   }
 }
